==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/kbibtexselectstring.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXSELECTSTRING_H
#define KBIBTEXSELECTSTRING_H

#include <qvbox.h>

class QListView;
class BibTeXFile;

class KBibTeXSelectString : public QVBox
{
    Q_OBJECT
public:
    KBibTeXSelectString( BibTeXFile * bibTeXFile, QWidget *parent = 0, const char *name = 0 );

    ~KBibTeXSelectString();

    static QString execute( BibTeXFile * bibTeXFile, QWidget *parent = 0, const char *name = 0 );
protected:
    QListView *m_listViewStrings;
};

#endif

==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/kbibtexselectstring.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXSELECTSTRING_H
#define KBIBTEXSELECTSTRING_H

#include <qvbox.h>

class QListView;
class BibTeXFile;

class KBibTeXSelectString : public QVBox
{
    Q_OBJECT
public:
    KBibTeXSelectString( BibTeX::BibTeXFile * bibTeXFile, QWidget *parent = 0, const char *name = 0 );

    ~KBibTeXSelectString();

    static QString execute( BibTeX::BibTeXFile * bibTeXFile, QWidget *parent = 0, const char *name = 0 );
protected:
    QListView *m_listViewStrings;
};

#endif
